import plotly.graph_objects as go


def plot_pie_chart(df, categorical_col, num_col, return_fig=False):
    """
    Plot a pie chart based on the provided DataFrame.

    Parameters:
        df (pandas.DataFrame): The DataFrame containing the data.
        categorical_col (str): The name of the column in the DataFrame that represents the categorical variable.
        num_col (str): The name of the column in the DataFrame that contains the numerical values.
        return_fig (bool, optional): If True (default is False), the function returns the Plotly Figure instead of showing it.

    Returns:
        plotly.graph_objs._figure.Figure (optional): A Plotly Figure representing the pie chart. 
                                                    (Returned only if 'return_fig' is True.)

    Example:
        >>> import pandas as pd
        >>> data = {
        ...     'Category': ['A', 'B', 'C', 'A', 'B', 'C'],
        ...     'Value': [100, 200, 300, 400, 500, 600]
        ... }
        >>> df = pd.DataFrame(data)
        >>> plot_pie_chart(df, 'Category', 'Value')
        # This will display a pie chart based on the 'Category' and 'Value' columns in the DataFrame.

        >>> pie_chart_figure = plot_pie_chart(df, 'Category', 'Value', return_fig=True)
        # This will return the Pie chart as a Plotly Figure without displaying it.
    """

    new_df = df[[categorical_col, num_col]]
    new_df = new_df.groupby(categorical_col).sum().reset_index()
    
    labels = new_df[categorical_col]
    values = new_df[num_col]

    fig = go.Figure(data=[go.Pie(labels=labels, values=values)])
    if return_fig :
        return fig
    else:
        fig.show()
    
